==> piwigo-2.1.5.tbz: www/piwigo/language/tr_TR/upgrade.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | Piwigo - a PHP based picture gallery                                  |
// +-----------------------------------------------------------------------+
// | Copyright(C) 2008-2010 Piwigo Team                  http://piwigo.org |
// | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
// | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
// +-----------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or modify  |
// | it under the terms of the GNU General Public License as published by  |
// | the Free Software Foundation                                          |
// |                                                                       |
// | This program is distributed in the hope that it will be useful, but   |
// | WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
// | General Public License for more details.                              |
// |                                                                       |
// | You should have received a copy of the GNU General Public License     |
// | along with this program; if not, write to the Free Software           |
// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, |
// | USA.                                                                  |
// +-----------------------------------------------------------------------+

$lang['Upgrade'] = "Gncellestirme";
$lang['This page proposes to upgrade your database corresponding to your old version of Piwigo to the current version. The upgrade assistant thinks you are currently running a <strong>release %s</strong> (or equivalent).'] = "Bu sayfa yeni srme Piwigo eski srmnden veritabani ykseltme neriyor. Ykseltme yardimcisi Su anda bir <strong> srm% (veya esdegeri) </ strong> alistiran dsnyor.";
$lang['Upgrade from version %s to %s'] = "%s srmden %s srmne gncellestir";
$lang['Statistics'] = "Istatistik";
$lang['total upgrade time'] = "toplam gncelleme zamani";
$lang['total SQL time'] = "tolam SQL zamani";
$lang['SQL queries'] = "SQL sorgulari";
$lang['Upgrade informations'] = "Gncelleme bilgileri";
$lang['Perform a maintenance check in [Administration>Tools>Maintenance] if you encounter any problem.'] = "Herhangi bir sorunla karsilasirsaniz, [Ynetim> Aralar> Bakim] dan bakim yapiniz.";
$lang['As a precaution, following plugins have been deactivated. You must check for plugins upgrade before reactiving them:'] = "Bir nlem olarak, asagidaki eklentiler devre disi olmustur.Onlari aktif etmeden nce eklentileri ykseltme iin kontrol etmelisiniz";
$lang['Only administrator can run upgrade: please sign in below.'] = "Sadece ynetici gncelleme alistirabilir: Asagidan giris yapin.";
$lang['You do not have access rights to run upgrade'] = "Gncelleme alistirmak iin yetkiniz yok";
$lang['All sub-categories of private categories become private'] = "zel kategorilerin tm alt kategorileri de zel olur";
$lang['User permissions and group permissions have been erased'] = "Kullanicilar ve gruplarin izinleri silinmistir";
$lang['Only thumbnails prefix and webmaster mail address have been saved from previous configuration'] = "Sadece kk resim n eki ve site yneticisi posta adresiniz nceki yapilandirman kaydedili";
$lang['In <i>%s</i>, before <b>?></b>, insert:'] = '<i>%s</i> iine, <b>?></b> nce, ekleyin:';


?>

==> piwigo-2.3.3.tbz: www/piwigo/language/tr_TR/upgrade.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | Piwigo - a PHP based photo gallery                                    |
// +-----------------------------------------------------------------------+
// | Copyright(C) 2008-2011 Piwigo Team                  http://piwigo.org |
// | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
// | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
// +-----------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or modify  |
// | it under the terms of the GNU General Public License as published by  |
// | the Free Software Foundation                                          |
// |                                                                       |
// | This program is distributed in the hope that it will be useful, but   |
// | WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
// | General Public License for more details.                              |
// |                                                                       |
// | You should have received a copy of the GNU General Public License     |
// | along with this program; if not, write to the Free Software           |
// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, |
// | USA.                                                                  |
// +-----------------------------------------------------------------------+

$lang['Upgrade'] = "Gncellestirme";
$lang['This page proposes to upgrade your database corresponding to your old version of Piwigo to the current version. The upgrade assistant thinks you are currently running a <strong>release %s</strong> (or equivalent).'] = "Bu sayfa yeni srme Piwigo eski srmnden veritabani ykseltme neriyor. Ykseltme yardimcisi Su anda bir <strong> srm% (veya esdegeri) </ strong> alistiran dsnyor.";
$lang['Upgrade from version %s to %s'] = "%s srmden %s srmne gncellestir";
$lang['Statistics'] = "Istatistik";
$lang['total upgrade time'] = "toplam gncelleme zamani";
$lang['total SQL time'] = "tolam SQL zamani";
$lang['SQL queries'] = "SQL sorgulari";
$lang['Upgrade informations'] = "Gncelleme bilgileri";
$lang['Perform a maintenance check in [Administration>Tools>Maintenance] if you encounter any problem.'] = "Herhangi bir sorunla karsilasirsaniz, [Ynetim> Aralar> Bakim] dan bakim yapiniz.";
$lang['As a precaution, following plugins have been deactivated. You must check for plugins upgrade before reactiving them:'] = "Bir nlem olarak, asagidaki eklentiler devre disi olmustur.Onlari aktif etmeden nce eklentileri ykseltme iin kontrol etmelisiniz";
$lang['Only administrator can run upgrade: please sign in below.'] = "Sadece ynetici gncelleme alistirabilir: Asagidan giris yapin.";
$lang['You do not have access rights to run upgrade'] = "Gncelleme alistirmak iin yetkiniz yok";
$lang['All sub-albums of private albums become private'] = 'Özel albümlerin alt albümleri de özel olur';
$lang['User permissions and group permissions have been erased'] = "Kullanicilar ve gruplarin izinleri silinmistir";
$lang['Only thumbnails prefix and webmaster mail address have been saved from previous configuration'] = "Sadece kk resim n eki ve site yneticisi posta adresiniz nceki yapilandirman kaydedili";
$lang['In <i>%s</i>, before <b>?></b>, insert:'] = '<i>%s</i> iine, <b>?></b> nce, ekleyin:';
$lang['As a precaution, following themes have been deactivated. You must check for themes upgrade before reactiving them:'] = 'nlem olarak, asagidaki temalar devre disi olmustur. Tekrar etkinlestirmeden nce gncelleme yapmalisiniz:';

?>
